# coding=utf-8
"""
An example of i18n with this module.
"""

from decimal import Decimal

from fluent_compiler.bundle import FluentBundle

from fluentogram import TranslatorHub, FluentTranslator, TranslatorRunner
from fluentogram.structure.fluent.transformers import MoneyTransformer

example_ftl_file_content = """
welcome = Welcome to the fluent aiogram addon!
greet-by-name = Hello, { $user }!
shop-success-payment = Your money, { $amount }, has been sent successfully.
"""


def demo() -> None:
    # main.py of bot:
    t_hub = TranslatorHub(
        {"ua": ("ru_UA", "ru", "en-US"),
         "ru": ("ru", "en-US"),
         "en": ("en-US",)},
        translators=[
            FluentTranslator(locale="en",
                             translator=FluentBundle.from_string("en-US", example_ftl_file_content,
                                                                 use_isolating=False))],
        root_locale="en",
    )

    # Middleware:
    t0: TranslatorRunner = t_hub.get_translator_by_locale("en")

    # Handler:
    print(t0.welcome())
    print(t0.greet.by.name(user="Alex"))
    print(t0.shop.success.payment(amount=MoneyTransformer(
        Decimal("500.05"), currency_display="symbol", currency="USD"
    )))

    # Going to be:
    """
    # Welcome to the fluent aiogram addon!
    # Hello, Alex!
    # Your money, $500.05, has been sent successfully.
    """
